@@ -1,7 +1,7 @@
 from math import ceil, floor
 from random import randint
 from sage.arith.all import gcd, lcm, nth_prime, srange, factorial, xgcd
-from sage.functions.all import log
+from sage.functions.all import log, sqrt
 from sage.matrix.constructor import matrix
 from sage.misc.all import prod
 from sage.misc.latex import view as show
@@ -11,10 +11,3 @@ from sage.rings.rational_field import QQ
 from sage.rings.polynomial.multi_polynomial_ideal import MPolynomialIdeal
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.symbolic.all import SR, pi
-
-# This function was moved in Sage 9.5, so earlier versions of Sage will get an
-# import error and must be imported from the old file
-try:
-    from sage.misc.all import sqrt
-except:
-    from sage.misc.other import sqrt
\ No newline at end of file
